pub struct PeerId { /* private fields */ }Expand description
Identifier of a peer of the network.
The data is a CIDv0 compatible multihash of the protobuf encoded public key of the peer as specified in specs/peer-ids.
Implementations
Sourceimpl PeerId
impl PeerId
Sourcepub fn try_from_multiaddr(address: &Multiaddr) -> Option<PeerId>
pub fn try_from_multiaddr(address: &Multiaddr) -> Option<PeerId>
Try to extract PeerId from Multiaddr.
Sourcepub fn from_multihash(multihash: Multihash) -> Result<PeerId, Multihash>
pub fn from_multihash(multihash: Multihash) -> Result<PeerId, Multihash>
Tries to turn a Multihash into a PeerId.
If the multihash does not use a valid hashing algorithm for peer IDs,
or the hash value does not satisfy the constraints for a hashed
peer ID, it is returned as an Err.
Sourcepub fn into_ed25519(&self) -> Option<[u8; 32]>
pub fn into_ed25519(&self) -> Option<[u8; 32]>
Convert PeerId into ed25519 public key bytes.